@@ -1,6 +1,6 @@
 # coding:utf-8
 import json
-import sys
+import gc
 import time
 import types
 import uuid
@@ -11,8 +11,6 @@ from LogCollectionFormatter.base_log import BaseLog
 from LogCollectionFormatter.insert_mq_tools import InsertQueue
 
 
-
-
 def check_resp_items(item):
     """
     递归检查嵌套字典中是否存在超长字符串
@@ -101,6 +99,7 @@ class MainLog(BaseLog):
                     self.debug('write_Internal_journallog  is Closed.Below is Abort.')
                     return f(*args, **kwargs)
                 channel, ret, str_ret = None, None, None
+                request_content, message, message_body, response_data = None, None, None, None
                 begin_time = time.time()
                 try:
                     request_time = datetime.datetime.now()
@@ -193,7 +192,8 @@ class MainLog(BaseLog):
                     end_time = time.time()
                     self.exception('Internal Journallog write Exception! after:%s', str(end_time - begin_time))
                 finally:
-                    pass
+                    del request_content, str_ret, message, message_body, response_data
+                    gc.collect()
                 return ret
             return decorated_function
         return log_decorated
